# Simple Qr Code Generator

This is a simple Qr Code Generator using Python.

## Installation
```bash
pip install genqr
```

## Usage
```python
from qr_generator import generate_qr_code

generate_qr_code("some link")
```
then you will get a qr code image in the same directory as the script.

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.


## License
[MIT](https://choosealicense.com/licenses/mit/)
